@@ -50,7 +50,6 @@ public class WsMailServiceImpl extends RemoteServiceServlet implements WsMailSer
 			_log.warn("TEST MODE - NO USER FOUND");
 			ASLSession session = SessionManager.getInstance().getASLSession(sessionID, getDevelopmentUser());
 			session.setScope(TEST_SCOPE);
-
 			return session;
 		}
 		else {
@@ -65,7 +64,7 @@ public class WsMailServiceImpl extends RemoteServiceServlet implements WsMailSer
 	 */
 	public String getDevelopmentUser() {
 		String user = TEST_USER;
-		//user = "massimiliano.assante";
+		//user = "gianpaolo.coro";
 		return user;
 	}
 	/**
@@ -84,7 +83,7 @@ public class WsMailServiceImpl extends RemoteServiceServlet implements WsMailSer
 				List<UserModel> users = um.listUsersByGroup(gm.getRootVO().getGroupId());
 				for (UserModel user : users) {
 					_log.trace("Trying to get additional info for "+user.getScreenName());
-					if (user.getScreenName().compareTo("test.user") != 0) { //skip test.user
+					if (user.getScreenName().compareTo(TEST_USER) != 0) { //skip test.user
 						portalUsers.add(new WSUser(user.getUserId(), user.getScreenName(), user.getFullname(), user.getEmail()));
 					}
 				}
@@ -99,7 +98,7 @@ public class WsMailServiceImpl extends RemoteServiceServlet implements WsMailSer
 				portalUsers.add(new WSUser("3462", "sandro.nesta", "Alessandro Nesta", "sandro@montreal.it"));
 				portalUsers.add(new WSUser("11464321", "samsung.mobile", "Samsung Mobile", "samsung@samsung.com"));	
 				
-				currUser = new WSUser("12345", "francesco.mangiacrapa", "Francesco Mangiacrapa", "assante@isti.cnr.it");
+				currUser = new WSUser("12345", getDevelopmentUser(), "Test User", "test.user@isti.cnr.it");
 			}
 		} catch (Exception e) {
 			_log.error("Error in server get all contacts ", e);
